# deriva-py
[![PyPi Version](https://img.shields.io/pypi/v/deriva.svg)](https://pypi.python.org/pypi/deriva)
[![PyPi Downloads](https://img.shields.io/pypi/dm/deriva.svg)](https://pypistats.org/packages/deriva)
[![PyPi Wheel](https://img.shields.io/pypi/wheel/deriva.svg)](https://pypi.python.org/pypi/deriva)
[![Python Versions](https://img.shields.io/pypi/pyversions/deriva.svg)](https://pypi.python.org/pypi/deriva)
[![License](https://img.shields.io/pypi/l/deriva.svg)](http://www.apache.org/licenses/LICENSE-2.0)

Python APIs and CLIs (Command-Line Interfaces) for the DERIVA platform.

## Installing

#### Installation via PyPi

Users are encouraged to download official releases from PyPi using `pip`.

If you have root access and wish to install into your system Python directory, use the following command:
```
$ sudo pip install deriva
```
Otherwise, it is recommended that you install into your user directory using the following command:
```
$ pip install --user deriva
```

#### Installation via Github

This project is actively developed. The `master` branch is expected to be stable and usable at every
commit. The APIs and CLIs may change in backward-incompatible ways, so if you depend on an interface you should remember
the GIT commit number.

Installing from source can also be accomplished with the `pip` utility.

If you have root access and wish to install into your system Python directory, use the following command:
```
$ sudo pip install git+https://github.com/informatics-isi-edu/deriva-py.git
```
Otherwise, it is recommended that you install into your user directory using the following command:
```
$ pip install --user git+https://github.com/informatics-isi-edu/deriva-py.git
```

## Documentation

See the `deriva-py` [documentation](http://docs.derivacloud.org/deriva-py/index.html) for additional information.  
